@@ -1,3 +1,4 @@
+import sysconfig
 import time
 
 from manafa.services.batteryStatsService import BatteryStatsService
@@ -7,9 +8,11 @@ from manafa.perfetto.perfettoParser import PerfettoCPUfreqParser
 from manafa.batteryStats.BatteryStatsParser import BatteryStatsParser
 import argparse
 from manafa.utils.Logger import log, LogSeverity
-from manafa.utils.Utils import execute_shell_command, mega_find
+from manafa.utils.Utils import execute_shell_command, mega_find, get_resources_dir
 
-DEFAULT_PROFILE="resources/profiles/power_profile.xml"
+MANAFA_RESOURCES_DIR = get_resources_dir()
+
+DEFAULT_PROFILE= MANAFA_RESOURCES_DIR + "/profiles/power_profile.xml"
 DEFAULT_TIMEZONE="GMT"
 
 def getLastBootTime(bts_file=None):
@@ -201,20 +204,32 @@ class EManafa(Service):
 		return "UTC" if default_tz == "WEST" else default_tz
 
 
+def have_connected_devices():
+	res,o,e = execute_shell_command("adb devices -l | grep -v attached")
+	return res == 0 and len(o) > 2
+
+
 if __name__ == '__main__':
 	default_resources_dir = "resources"
 	parser = argparse.ArgumentParser()
 	parser.add_argument("-p", "--profile", default=None, type=str)
 	parser.add_argument("-t", "--timezone", default=None, type=str)
+	parser.add_argument("-pft", "--perfettofile", default=None, type=str)
+	parser.add_argument("-bts", "--batstatsfile", default=None, type=str)
 	args = parser.parse_args()
+
+	has_device_conn = have_connected_devices()
+	invalid_file_args = (args.perfettofile is None or args.batstatsfile is None )
+	if not has_device_conn and invalid_file_args:
+		log("Fatal error. No connected devices and result files submittted for analysis", LogSeverity.FATAL)
+		exit(-1)
 	g = EManafa(power_profile=args.profile, timezone=args.timezone, resources_dir=default_resources_dir)
-	g.init()
-	g.start()
-	time.sleep(7) # do work
-	bts_file, pf_file = g.stop()
-	#bts_file = "results/batterystats/bstats-1615831762.log"
-	#pf_file = "results/perfetto/trace-1615831762.systrace"
-	g.parseResults(bts_file, pf_file)
+	if has_device_conn and invalid_file_args:
+		g.init()
+		g.start()
+		time.sleep(7) # do work
+		args.batstatsfile, args.perfettofile = g.stop()
+	g.parseResults(args.batstatsfile, args.perfettofile)
 	begin = g.bat_events.events[0].time
 	end = g.bat_events.events[-1].time
 	consumption, per_component_consumption = g.getConsumptionInBetween(begin, end)
