@@ -9,13 +9,15 @@ from ..utils.Utils import execute_shell_command
 
 class BatteryStatsService(Service):
 	"""docstring for BatteryStatsService"""
-	def __init__(self, output_res_folder="batterystats"):
+	def __init__(self,boot_time=0, output_res_folder="batterystats"):
 		Service.__init__(self,output_res_folder)
+		self.boot_time = boot_time
 
 	def config(self,**kwargs):
 		pass
 
-	def init(self,**kwargs):
+	def init(self,boot_time=0,**kwargs):
+		self.boot_time = boot_time
 		self.clean()
 
 	def start(self):
@@ -25,7 +27,7 @@ class BatteryStatsService(Service):
 		
 		if fil is None:
 			uid_file = execute_shell_command("date +%s")[1].strip()
-		filename = self.results_dir + "/bstats-%s.log" % uid_file
+		filename = self.results_dir + "/bstats-%s-%s.log" % (uid_file, str(self.boot_time))
 		execute_shell_command("adb shell dumpsys batterystats --history > %s" % filename)
 		#print(colored("Output file  %s" % filename, "green"))
 		log("Output file  %s" % filename)
